# reconchess-tools: utilities to aid bot development for reconchess

Getting started developing bots in python for the [Reconnaissance Blind Chess](https://rbc.jhuapl.edu/) competition from JHU APL is already simple thanks to the [reconchess](https://github.com/reconnaissanceblindchess/reconchess) package. The code in this repository builds on that foundation to make it equally easy to move beyond beginner bot development. It provides utilities for multi-hypothesis-tracking (MHT), MHT game replays, sense and move simulation, and dominated action detection.

See the example bot (reconchess_tools/example_bot/bot.py) for an overview of the capabilities included in this repository. You can run a local game and view the replay using the cli: `reconchess-tools bot-match reconchess.bots.trout_bot reconchess_tools.example_bot.bot`.
